## 1.0.3
### Fixed
* Incorrect raw data extraction for location and owner in `Search.build` function

## 1.0.2
### Added
* Support for full Leboncoin URL in `client.search(url=...)`
* New `shippable` argument in the `search` function

### Fixed
* Incorrect enum key assignment in the `build_search_payload_with_args` function

## 1.0.1
### Added
* Realistic `Sec-Fetch-*` headers to prevent 403 errors

## 1.0.0
* Initial release